@@ -1,9 +1,12 @@
 """cloud_sptheme.ext.relbar_toc - addes TOC entry to relbar"""
 import os.path
-import re
 import logging; log = logging.getLogger(__name__)
+from cloud_sptheme import __version__
 
 def insert_toc(app, pagename, templatename, ctx, event_arg):
+    if "rellinks" not in ctx:
+        # e.g. json builder 'genindex' page
+        return
     links = ctx['rellinks']
 
     #remove any existing toc (present on some pages)
@@ -21,12 +24,18 @@ def insert_toc(app, pagename, templatename, ctx, event_arg):
         idx += 1
 
     #insert our toc entry
-    #FIXME: there's probably a MUCH better / less broken way to do this
-    path = os.path.split(os.path.splitext(ctx['pathto']("contents"))[0])[1]
-    ##path = os.path.splitext(ctx['pathto']("contents"))[0]
-    ##if path == '':
-    ##    path = pagename
+    # FIXME: there's probably a MUCH better / less broken way to do this
+    if "pathto" in ctx:
+        # normal html builder
+        path = os.path.split(os.path.splitext(ctx['pathto']("contents"))[0])[1]
+    else:
+        # hardcode path for special "json" builder --
+        # seems to always use docroot-relative paths
+        path = "contents"
     links.insert(idx, (path, "Table Of Contents", "C", "toc"))
 
 def setup(app):
     app.connect('html-page-context', insert_toc)
+
+    # identifies the version of our extension
+    return {'version': __version__}
